==> datapipelab-0.1.4-py3-none-any.whl: datapipelab/pipeline_config.py <==
import json5


class PipelineConfig:
    def __init__(self, config_file, params):
        print(config_file)
        self.params = params
        self.config_file = config_file
        # If config file is instance of string, it is a path to the config file
        self.config_file = config_file
        if isinstance(self.config_file, str):
            self.load_json_config_file()
        elif isinstance(self.config_file, dict):
            self.pipeline_settings = config_file
        else:
            raise ValueError("Invalid config file type. Must be a string or a dictionary.")
        self.sources = {}
        self.processors = {}
        self.sinks = {}

    def load_json_config_file(self):
        with open(self.config_file, 'r') as f:
            # Read the file as a text file
            json_config_file = f.read()
            # Replace the placeholders with the actual values
            for key, value in self.params.items():
                json_config_file = json_config_file.replace(f"{{{key}}}", value)
            # Convert to JSON file
            self.pipeline_settings = json5.loads(json_config_file)

    def create_pipeline_nodes(self):
        for component in self.pipeline_settings:
            if component['type'] == 'source':
                source = {
                    'input_format': component['format'],
                    'name': component['name'],
                    'input_type': component['source'],
                    'options': component['options']
                }
                self.sources[component['name']] = source
            elif component['type'] == 'processor':
                processor = {
                    'format': component['format'],
                    'name': component['name'],
                    'options': component['options']
                }
                parents = component['options'].get('parents', [])
                parent_sources = []
                for parent in parents:
                    parent_source = self.sources.get(parent)
                    if not parent_source:
                        parent_processor = self.processors.get(parent)
                        if not parent_processor:
                            raise ValueError(f"Parent '{parent}' not found")
                        parent_source = parent_processor['source']
                    parent_sources.append(parent_source)
                processor['source'] = parent_sources
                self.processors[component['name']] = processor
            elif component['type'] == 'sink':
                sink = {
                    'output_format': component['format'],
                    'name': component['name'],
                    'output_type': component['sink'],
                    'options': component['options']
                }
                parent = component['options']['parents'][0]
                parent_source = self.sources.get(parent)
                if not parent_source:
                    parent_processor = self.processors.get(parent)
                    if not parent_processor:
                        raise ValueError(f"Parent '{parent}' not found")
                    parent_source = parent_processor['source']
                sink['source'] = parent_source
                self.sinks[component['name']] = sink
            else:
                raise ValueError(f"Invalid component type '{component['type']}'")

==> datapipelab-0.1.5-py3-none-any.whl: datapipelab/pipeline_config.py <==
import json5


class PipelineConfig:
    def __init__(self, config_file, params):
        print(config_file)
        self.params = params
        self.config_file = config_file
        # If config file is instance of string, it is a path to the config file
        self.config_file = config_file
        if isinstance(self.config_file, str):
            self.load_json_config_file()
        elif isinstance(self.config_file, list):
            self.pipeline_settings = config_file
        else:
            raise ValueError("Invalid config file type. Must be a string or a list.")
        self.sources = {}
        self.processors = {}
        self.sinks = {}

    def load_json_config_file(self):
        with open(self.config_file, 'r') as f:
            # Read the file as a text file
            json_config_file = f.read()
            # Replace the placeholders with the actual values
            for key, value in self.params.items():
                json_config_file = json_config_file.replace(f"{{{key}}}", value)
            # Convert to JSON file
            self.pipeline_settings = json5.loads(json_config_file)

    def create_pipeline_nodes(self):
        for component in self.pipeline_settings:
            if component['type'] == 'source':
                source = {
                    'input_format': component['format'],
                    'name': component['name'],
                    'input_type': component['source'],
                    'options': component['options']
                }
                self.sources[component['name']] = source
            elif component['type'] == 'processor':
                processor = {
                    'format': component['format'],
                    'name': component['name'],
                    'options': component['options']
                }
                parents = component['options'].get('parents', [])
                parent_sources = []
                for parent in parents:
                    parent_source = self.sources.get(parent)
                    if not parent_source:
                        parent_processor = self.processors.get(parent)
                        if not parent_processor:
                            raise ValueError(f"Parent '{parent}' not found")
                        parent_source = parent_processor['source']
                    parent_sources.append(parent_source)
                processor['source'] = parent_sources
                self.processors[component['name']] = processor
            elif component['type'] == 'sink':
                sink = {
                    'output_format': component['format'],
                    'name': component['name'],
                    'output_type': component['sink'],
                    'options': component['options']
                }
                parent = component['options']['parents'][0]
                parent_source = self.sources.get(parent)
                if not parent_source:
                    parent_processor = self.processors.get(parent)
                    if not parent_processor:
                        raise ValueError(f"Parent '{parent}' not found")
                    parent_source = parent_processor['source']
                sink['source'] = parent_source
                self.sinks[component['name']] = sink
            else:
                raise ValueError(f"Invalid component type '{component['type']}'")
